#include <stdio.h>
#include <math.h>

double drag(double h, double v, double u) {
// Oblicza siłę oporu dynamicznego samolotu F-15.
// Model atmosfery wg Seywalda.
// h - wysokość [m] 
// v - prędkość względem powietrza [m/s]
// u - sterowanie sterem wysokości [-12, 12]
    
  double S     =  60.;     // powierzchnia "natarcia" samolotu [m^2]
  double m     =  16818.;  // masa [kg]
  double g     =  9.80665;// przyspieszenie grawitacyjne (stałe!!!) [m/s^2]
  
  double z1    =  3.48643241e-5;
  double z2    = -3.50991865e-9;
  double z3    =  8.33000535e-14;
  double z4    = -1.15219733e-18;
  
  double yy0   =  1.0228055;
  double yy1   = -0.12122693e-3;
  double wsp_rho= 1.225;

  double th0   = 292.1e0;
  double th1   = -8.87743e-3;
  double th2   =  0.193315e-6;
  double th3   =  3.72e-12;

  double a0    = 20.0468;
   
  double ck[6][4] ={{ 0.0261059846050,  1.37368651246,  1.23001735612,  14.2392902737},
                    {-0.0857043966269, -4.57116286752, -2.97244144190, -32.4759126471},
                    { 0.107863115049,   5.72789877344,  2.78009092756,  29.6838743792},
                    {-0.0644772018636, -3.25219000620, -1.16227834301, -13.3316812491},
                    { 0.0164933626507,  0.729821847445, 0.181868987624,  2.87165882405},
                    { 0,                0,              0,              -0.227239723756}};
  double h2=h*h, h3=h2*h, h4=h2*h2;

  double yy = yy0*(exp(z1*h + z2*h2 + z3*h3 + z4*h4)-1.0) + yy1*h;

  double rho = wsp_rho*exp(yy);              // gęstość powietrza [kg/m^3]

  double q = 0.5*rho*S*v*v;                  // ciśnienie dynamiczne [N]

  double th = th0 + th1*h + th2*h2 + th3*h3; // temperatura [K]

  double M = v/(a0*sqrt(th));                // prędkość w machach
   
  double M2=M*M, M3=M2*M, M4=M3*M, M5=M4*M;
  double vM[6] = {1, M, M2, M3, M4, M5};
  double cn=0.0, cd=0.0, kn=0.0, kd=0.0;
  int i;
  for(i=0; i<6; i++) {
      cn += vM[i]*ck[i][0];
      cd += vM[i]*ck[i][1];
      kn += vM[i]*ck[i][2];
      kd += vM[i]*ck[i][3];
  }
  double  C =cn/cd, K = kn/kd;
  
  return q*C + m*m*g*g*K/q *u*u;
}

int main(void) {
    double h, v, u, D;
    printf("podaj wysokosc [0, 20000] m ");
    scanf("%lf", &h);
    
    printf("podaj predkosc [50, 750] m/s ");
    scanf("%lf",&v);
    
    printf("podaj sterowanie [-12, 12] ");
    scanf("%lf",&u);
    
    D = drag(h,v,u);
    
    printf("Sila oporu = : %f [N]\n", D);
    
    return 0;

}